let env = null

// const base64 = import.meta.glob('./base64.js');
import base64 from './base64.js'
import Crypto from './crypto.js'
console.log(Crypto, 'crypto');
// import.meta.globEager('./hmac.js');
// import.meta.globEager('./sha1.js');
// const Crypto = import.meta.glob('./crypto.js');
async function getConfig(data) {
    // const data = await uni.$ca.upload()
    env = {
        //aliyun OSS config
        uploadImageUrl: `https://${data.Bucket}.${data.EndPoint}`,//阿里云上传域名
        // uploadImageUrl: 'https://crecash.aliyuncs.com',
        AccessKeySecret: data.AccessKeySecret,//Secret，登录oss控制台查看
        OSSAccessKeyId: data.AccessKeyId,//KeyId，登录oss控制台查看
        timeout: 87600,
        bucket: data.Bucket,
        securityToken: data.SecurityToken,
        maxSize: 15 * 1024 * 1024 //上传文件的大小限制,15M
    };
}

/*
 *上传文件到阿里云oss
 *@param - filePath :文件的本地资源路径
  @param - path :上传oss哪个路径下
  postfix : 文件后缀
 *@param - successc:成功回调
 *@param - failc:失败回调
 */
const uploadFile = async function (filePath,ossData, props, suffix = 'png') {
    if (!filePath || filePath.length < 9) {
        uni.toast('文件错误')
        return;
    }
    await getConfig(ossData)
    const aliyunServerURL = env.uploadImageUrl; //OSS地址，https
    let policyBase64 = getPolicyBase64();
    let signature = getSignature(policyBase64);
    const aliyunKey = `${ossData.Bucket}/${Math.random().toString(32).slice(2)}.${suffix}`
    return new Promise((r, j) => {
        uni.uploadFile({
            url: aliyunServerURL, //开发者服务器 url
            filePath: filePath, //要上传文件资源的路径
            name: 'file', //必须填file
            formData: {
                //存放文件命名格式：自定义时间戳给文件名字(可以自己改)
                'key': aliyunKey,
                'policy': policyBase64,
                'OSSAccessKeyId': env.OSSAccessKeyId,
                'x-oss-security-token': env.securityToken,
                'success_action_status': '200',
                'signature': signature
            },
            success: function (res) {
                r({
                    ...res,
                    code: res.statusCode === 200 ? 0 : -1,
                    data: res.statusCode === 200 ? `/${aliyunKey}` : ''
                });
            },
			fail(err) {
				console.log('err====',err)
			}
        }).onProgressUpdate((e) => {
            props.onProgress?.(e)
        })
    })
}

const getPolicyBase64 = function () {
    let date = new Date();
    date.setHours(date.getHours() + env.timeout);
    let srcT = date.toISOString();
    const policyText = {
        "expiration": srcT, //设置该Policy的失效时间，超过这个失效时间之后，就没有办法通过这个policy上传文件了 
        "conditions": [
            ["content-length-range", 0, env.maxSize] // 设置上传文件的大小限制,5mb
        ]
    };

    const policyBase64 = base64.encode(JSON.stringify(policyText));
    return policyBase64;
}


function izArrayBufferToBase64(buffer) {
    var binary = '';
    var bytes = new Uint8Array(buffer);
    var len = bytes.byteLength;
    for (var i = 0; i < len; i++) {
        binary += String.fromCharCode(bytes[i]);
    }
    let signature = base64.encode(binary)
    return signature
}


const getSignature = function (policyBase64) {
    const accesskey = env.AccessKeySecret;
    const bytes = Crypto.HMAC(Crypto.SHA1, policyBase64, accesskey, {
        asBytes: true
    });
    const signature = izArrayBufferToBase64(bytes)
    return signature;
}


export default uploadFile